@@ -8,7 +8,11 @@
 #===========================================
 # output: objPoint: ['flow','fn','indexMax','index','x','y','range','doppler','area','ptsNum','cid']
 # v0.1.0 : 2021/04/21 release
- 
+# v0.1.1: 2021/05/02 release
+# v0.1.1 : 2021/05/02 release
+#    Add:    getRecordData(self,frameNum):
+#            readFile(self,fileName):
+#
 
 import serial
 import time
@@ -19,7 +23,7 @@ from dataclasses import dataclass
 
 @dataclass
 class header:
-	version = 'v0.1.0'
+	version = 'v0.1.1'
 	frameNumber = 0
 
 
@@ -31,6 +35,11 @@ class roadwayTmdISK_kv:
 	
 	port = ""
 	v21_col_names_rt = ['flow','fn','indexMax','index','x','y','range','doppler','area','ptsNum','cid']
+	v21_col_names_file = ['fn','x','y','range','doppler','area','ptsNum','NotObject','MAN','MotorCycle','car','CAR']
+	
+	sim_startFN = 0
+	sim_stopFN  = 0 
+	v21simo = []
 	
 	def __init__(self,port):
 		self.port = port
@@ -122,9 +131,9 @@ class roadwayTmdISK_kv:
 						compIdx = 0 if (indexMax - 1) < 0 else indexMax - 1
 						if index == compIdx:
 							lstate = 'idle'
-							v21pd = self.list2df(True,v21df) 
+							v21pd = v21df
 							v21df =([]) 
-							return v21pd
+							return self.list2df(True,v21pd) 
 						else:
 							lstate = 'iNext'
 							
@@ -153,4 +162,30 @@ class roadwayTmdISK_kv:
 					
 					return self.list2df(False,v21df) 
 					
+	#================== For playback method ======================================
+	# add in v0.1.1
+	#================== output data based on frameNum ==================
+	def getRecordData(self,frameNum):
+		s_fn = frameNum + self.sim_startFN
+		v21d = self.v21simo[self.v21simo['fn'] == float(s_fn)]
+		chk = 0
+		if v21d.count != 0:
+			chk = 1
+		return (chk,v21d)
+	#================== read data from file for use
+	def readFile(self,fileName):
+		#fileName = "pc32021-03-19-10-02-17.csv"  
+		#df = pd.read_csv(fileName, error_bad_lines=False, warn_bad_lines=False) 
+		self.fileName = fileName 
+		#          ['time','fN','type','elv','azimuth','range' ,'doppler','sx', 'sy', 'sz']
+		#df = pd.read_csv(self.fileName, names = self.v21_col_names_file, dtype={'fn': float,'indexMax': float,'index':float,'x':float,'y':float,'range':float,'doppler':float,'area':float,'ptsNum':float,'cid':float}) 
+		df = pd.read_csv(self.fileName, 
+			names = self.v21_col_names_file,
+			skiprows = 1, #delete header
+			error_bad_lines=False,
+			dtype={'fn': float,'x':float,'y':float,'range':float,'doppler':float,'area':float,'ptsNum':float,'NotObject':int,'MAN':int,'MotorCycle':int,'car':int,'CAR':int}) 
 			
+		df.dropna()
+		#print("------------------- df --------------------shape:{:}".format(df.shape))
+		self.v21simo = df
+		return df
